@@ -11,6 +11,7 @@
 #include <QTest>
 
 using namespace KUnitConversion;
+using namespace Plasma;
 
 class ConverterRunnerTest : public AbstractRunnerTest
 {
@@ -108,7 +109,7 @@ void ConverterRunnerTest::testQuery()
     QFETCH(QString, expectedText);
 
     launchQuery(query);
-    const QList<Plasma::QueryMatch> matches = manager->matches();
+    const QList<QueryMatch> matches = manager->matches();
     QCOMPARE(matches.count(), 1);
     QCOMPARE(matches.first().text(), expectedText);
 }
