@@ -7,25 +7,24 @@
 
 #include <KLocalizedString>
 #include <QEventLoop>
+#include <QMutex>
+#include <QMutexLocker>
 #include <QStringList>
 #include <QTimer>
 
-static const char CONFIG_TRIGGERWORD[] = "triggerWord";
+namespace
+{
+const char CONFIG_TRIGGERWORD[] = "triggerWord";
+QMutex s_initMutex;
+}
 
 DictionaryRunner::DictionaryRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : AbstractRunner(parent, metaData, args)
 {
-    m_engine = new DictionaryMatchEngine(m_consumer.dataEngine(QStringLiteral("dict")), this);
-
     setPriority(LowPriority);
     setObjectName(QLatin1String("Dictionary"));
 }
 
-void DictionaryRunner::init()
-{
-    reloadConfiguration();
-}
-
 void DictionaryRunner::reloadConfiguration()
 {
     KConfigGroup c = config();
@@ -36,10 +35,10 @@ void DictionaryRunner::reloadConfiguration()
     } else {
         setMatchRegex(QRegularExpression());
     }
-    setSyntaxes({Plasma::RunnerSyntax(i18nc("Dictionary keyword", "%1:q:", m_triggerWord), i18n("Finds the definition of :q:."))});
+    setSyntaxes({RunnerSyntax(i18nc("Dictionary keyword", "%1:q:", m_triggerWord), i18n("Finds the definition of :q:."))});
 }
 
-void DictionaryRunner::match(Plasma::RunnerContext &context)
+void DictionaryRunner::match(RunnerContext &context)
 {
     QString query = context.query();
     if (query.startsWith(m_triggerWord, Qt::CaseInsensitive)) {
@@ -48,20 +47,30 @@ void DictionaryRunner::match(Plasma::RunnerContext &context)
     if (query.isEmpty()) {
         return;
     }
+
+    {
+        QEventLoop loop;
+        QTimer::singleShot(400, &loop, [&loop]() {
+            loop.quit();
+        });
+        loop.exec();
+    }
+    if (!context.isValid()) {
+        return;
+    }
+    QString returnedQuery;
+    QMetaObject::invokeMethod(&m_dictEngine, "requestDefinition", Qt::QueuedConnection, Q_ARG(const QString &, query));
     QEventLoop loop;
-    QTimer::singleShot(400, &loop, [&loop]() {
+    connect(&m_dictEngine, &DictEngine::definitionRecieved, &loop, [&loop, &query, &returnedQuery, &context](const QString &html) {
+        returnedQuery = html;
         loop.quit();
     });
     loop.exec();
-    if (!context.isValid()) {
-        return;
-    }
-    QString returnedQuery = m_engine->lookupWord(query);
-    if (!context.isValid()) {
+    if (!context.isValid() || returnedQuery.isEmpty()) {
         return;
     }
 
-    static const QRegExp removeHtml(QLatin1String("<[^>]*>"));
+    static const QRegularExpression removeHtml(QLatin1String("<[^>]*>"));
     QString definitions(returnedQuery);
     definitions.remove(QLatin1Char('\r')).remove(removeHtml);
     while (definitions.contains(QLatin1String("  "))) {
@@ -73,22 +82,23 @@ void DictionaryRunner::match(Plasma::RunnerContext &context)
     }
     lines.removeFirst();
 
-    QList<Plasma::QueryMatch> matches;
+    QList<QueryMatch> matches;
     int item = 0;
-    static const QRegExp partOfSpeech(QLatin1String("(?: ([a-z]{1,5})){0,1} [0-9]{1,2}: (.*)"));
+    static const QRegularExpression partOfSpeech(QLatin1String("(?: ([a-z]{1,5})){0,1} [0-9]{1,2}: (.*)"));
     QString lastPartOfSpeech;
     for (const QString &line : std::as_const(lines)) {
-        if (partOfSpeech.indexIn(line) == -1) {
+        const auto reMatch = partOfSpeech.match(line);
+        if (!reMatch.hasMatch()) {
             continue;
         }
-        if (!partOfSpeech.cap(1).isEmpty()) {
-            lastPartOfSpeech = partOfSpeech.cap(1);
+        if (!reMatch.capturedView(1).isEmpty()) {
+            lastPartOfSpeech = reMatch.captured(1);
         }
-        Plasma::QueryMatch match(this);
+        QueryMatch match(this);
         match.setMultiLine(true);
-        match.setText(lastPartOfSpeech + QLatin1String(": ") + partOfSpeech.cap(2));
+        match.setText(lastPartOfSpeech + QLatin1String(": ") + reMatch.captured(2));
         match.setRelevance(1 - (static_cast<double>(++item) / static_cast<double>(lines.length())));
-        match.setType(Plasma::QueryMatch::InformationalMatch);
+        match.setType(QueryMatch::InformationalMatch);
         match.setIconName(QStringLiteral("accessories-dictionary"));
         matches.append(match);
     }
